@@ -1,9 +1,9 @@
-//golangcitest:args -Egoimports
+//golangcitest:config_path testdata/goimports.yml
 package testdata
 
 import (
 	"fmt" // want "File is not properly formatted"
-	"github.com/golangci/golangci-lint/pkg/config"
+	"github.com/golangci/golangci-lint/v2/pkg/config"
 )
 
 func Bar() {
