@@ -103,7 +103,7 @@ func fetchAllReleases(ctx context.Context) ([]release, error) {
 					EndCursor   githubv4.String
 					HasNextPage bool
 				}
-			} `graphql:"releases(first: 100, orderBy: { field: CREATED_AT, direction: DESC }, after: $releasesCursor)"`
+			} `graphql:"releases(first: 50, orderBy: { field: CREATED_AT, direction: DESC }, after: $releasesCursor)"`
 		} `graphql:"repository(owner: $owner, name: $name)"`
 	}
 
@@ -219,10 +219,9 @@ func parseVersion(s string) (*version, error) {
 		return nil, fmt.Errorf("version %q should start with %q", s, vPrefix)
 	}
 
-	parts := strings.Split(strings.TrimPrefix(s, vPrefix), ".")
-
 	var nums []int
-	for _, part := range parts {
+
+	for part := range strings.SplitSeq(strings.TrimPrefix(s, vPrefix), ".") {
 		num, err := strconv.Atoi(part)
 		if err != nil {
 			return nil, fmt.Errorf("failed to parse version %q: %w", s, err)
